: This forces SH files to create target in same directory as SH file.
: This is so that make depend always knows where to find SH derivatives.

case "$0" in
*/*) cd `expr X$0 : 'X\(.*\)/'` ;;
esac

if test -f config.sh; then TOP=.;
elif test -f ../config.sh; then TOP=..;
elif test -f ../../config.sh; then TOP=../..;
elif test -f ../../../config.sh; then TOP=../../..;
elif test -f ../../../../config.sh; then TOP=../../../..;
else
	echo "Can't find config.sh."; exit 1
fi

: Find absolute path name for TOP.  This is needed when we cd to TOP
: to run perl on autosplit.
oldpwd=`pwd`; cd $TOP; ABSTOP=`pwd`; cd $oldpwd

case $CONFIG in
'')
	. $TOP/config.sh
	;;
esac

: Find out directory name.  This is also the extension name.
ext=`pwd | $sed -e 's@.*/@@'`

: This extension might have its own typemap
if test -f typemap; then
	exttypemap='typemap'
else
	exttypemap=''
fi

: This extension might need additional libraries.
#potential_libs=" -lXaw -lXmu -lXext -lXt -lX11 "
. $TOP/ext/util/extliblist
statloadlibs="$statloadlibs /lib/libXaw.a /lib/libXmu.a /lib/libXext.a /lib/libXt.a /lib/libX11.a "

: This extension might need bootstrap support
if test -f ${ext}_BS; then
	bootdep=${ext}_BS
else
	bootdep=''
fi

echo "Extracting ext/$ext/Makefile (with variable substitutions)"
: This section of the file will have variable substitutions done on it.
: Move anything that needs config subs from !NO!SUBS! section to !GROK!THIS!.
: Protect any dollar signs and backticks that you do not want interpreted
: by putting a backslash in front.  You may delete these comments.
$spitshell >Makefile << !GROK!THIS!
#
# This Makefile is for the $ext extension to perl.
# 
CC = $cc
RANLIB = $ranlib
TOP = $TOP
ABSTOP = $ABSTOP
LDFLAGS = $ldflags
CLDFLAGS = $ldflags
SMALL = $small
LARGE = $large $split

# To use an alternate make, set \$altmake in config.sh.
MAKE = ${altmake-make}

EXT = $ext

# $ext might have its own typemap
EXTTYPEMAP = $exttypemap

# $ext might have its own bootstrap support
BOOTDEP  = $bootdep
BOOTSTRAP  = $ext.bs

# The following are used to build and install shared libraries for
# dynamic loading.
LDDLFLAGS = $lddlflags
CCDLFLAGS = $ccdlflags
CCCDLFLAGS = $cccdlflags
SO = $so

# $ext might need to be linked with some extra libraries.
# EXTRALIBS =  full list of libraries needed for static linking.
#		Only those libraries that actually exist are included.
# DYNLOADLIBS = list of those libraries that are needed but can be
#		linked in dynamically on this platform.  On SunOS, for
#		example, this would be .so* libraries, but not archive
#		libraries.  The bootstrap file is installed only if
#		this list is not empty.
# STATLOADLIBS = list of those libraries which must be statically
#		linked into the shared library.  On SunOS 4.1.3, 
#		for example,  I have only an archive version of
#		-lm, and it must be linked in statically.
EXTRALIBS = $extralibs
DYNALOADLIBS  = $dynaloadlibs
STATLOADLIBS = $statloadlibs

!GROK!THIS!

$spitshell >>Makefile <<'!NO!SUBS!'

# Where to put things:
AUTO = $(TOP)/lib/auto
INSTALLBOOT = $(AUTO)/$(EXT)/$(EXT).bs
INSTALLDYNAMIC = $(AUTO)/$(EXT)/$(EXT).$(SO)
INSTALLSTATIC = $(TOP)/$(EXT).a
INSTALLPM = $(TOP)/lib/$(EXT).pm

PERL = $(ABSTOP)/miniperl
XSUBPP = $(TOP)/ext/xsubpp
SHELL = /bin/sh
CCCMD = `sh $(shellflags) $(TOP)/cflags $@`

.c.o:
	$(CCCMD) $(CCCDLFLAGS) -I$(TOP) $*.c

all:	dynamic
# Phony target to force checking subdirectories.
FORCE:

!NO!SUBS!

$spitshell >>Makefile << !GROK!THIS!
# $ext extension

# Target for Dynamic Loading:
dynamic:	\$(TOP)/lib/auto/${ext}/${ext}.${so} \$(TOP)/lib/${ext}.pm $installboot

\$(TOP)/lib/auto/${ext}/${ext}.${so}: ${ext}.o suplibsx.o sx/libsx.a
	@test -d \$(TOP)/lib/auto || mkdir \$(TOP)/lib/auto
	@test -d \$(TOP)/lib/auto/${ext} || mkdir \$(TOP)/lib/auto/${ext}
	ld \$(LDDLFLAGS) -o \$@ ${ext}.o suplibsx.o sx/libsx.a \$(STATLOADLIBS)

$bsnote
\$(TOP)/lib/auto/${ext}/${ext}.bs:	${ext}.bs
	cp ${ext}.bs \$@

# Target for Static Loading:
static: \$(TOP)/${ext}.a \$(TOP)/lib/${ext}.pm \$(TOP)/ext.libs

$(TOP)/ext.libs:	Makefile
	echo \$(EXTRALIBS) >> \$(TOP)/ext.libs

\$(TOP)/${ext}.a:	${ext}.o sx/libsx.a
	cp sx/libsx.a \$@
	ar r \$@ ${ext}.o
	\$(RANLIB) \$@

${ext}.c:	${ext}.xs \$(TOP)/ext/xsubpp \$(TOP)/ext/typemap \$(EXTTYPEMAP) \$(TOP)/cflags
	\$(PERL) \$(XSUBPP) ${ext}.xs >tmp
	mv tmp \$@

\$(TOP)/lib/${ext}.pm:	${ext}.pm
	cp ${ext}.pm \$(TOP)/lib/${ext}.pm
	cd \$(TOP); \$(PERL) autosplit $ext

sx/libsx.a:	FORCE
	@cd sx;  \\
	if test ! -f Makefile ; then \\
	test -f Makefile.SH && sh Makefile.SH ; \\
	fi ; \
	\$(MAKE)

clean:
	cd sx; \$(MAKE) clean
	rm -f *.o *.a mon.out core $ext.c so_locations

realclean: 	clean
	cd sx; \$(MAKE) realclean
	rm -f makefile Makefile
	rm -f \$(TOP)/lib/$ext.pm
	rm -rf \$(TOP)/lib/auto/$ext

purge:	realclean

$ext.o :	\$(TOP)/EXTERN.h
$ext.o :	\$(TOP)/perl.h
$ext.o :	\$(TOP)/embed.h
$ext.o :	\$(TOP)/config.h
$ext.o :	\$(TOP)/unixish.h
$ext.o :	\$(TOP)/handy.h
$ext.o :	\$(TOP)/regexp.h
$ext.o :	\$(TOP)/sv.h
$ext.o :	\$(TOP)/util.h
$ext.o :	\$(TOP)/form.h
$ext.o :	\$(TOP)/gv.h
$ext.o :	\$(TOP)/cv.h
$ext.o :	\$(TOP)/opcode.h
$ext.o :	\$(TOP)/op.h
$ext.o :	\$(TOP)/cop.h
$ext.o :	\$(TOP)/av.h
$ext.o :	\$(TOP)/hv.h
$ext.o :	\$(TOP)/mg.h
$ext.o :	\$(TOP)/scope.h
$ext.o :	\$(TOP)/pp.h
$ext.o :	\$(TOP)/proto.h
$ext.o :	\$(TOP)/XSUB.h 

Makefile:	Makefile.SH \$(TOP)/config.sh ; /bin/sh Makefile.SH
\$(TOP)/config.h:	\$(TOP)/config.sh; cd \$(TOP); /bin/sh config_h.SH
\$(TOP)/embed.h:	\$(TOP)/config.sh; cd \$(TOP); /bin/sh embed_h.SH
\$(TOP)/cflags:	\$(TOP)/config.sh; cd \$(TOP); /bin/sh cflags.SH

!GROK!THIS!
chmod 755 Makefile
$eunicefix Makefile
